abacusai.python_function — AbacusAI documentation

# `abacusai.python_function`

## Module Contents

### Classes

`PythonFunction` | Customer created python function

class abacusai.python_function.PythonFunction(client, notebookId=None, name=None, createdAt=None, functionVariableMappings=None, functionName=None, codeSource={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Customer created python function

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - notebookId (str) – The unique identifier of the notebook used to spin up the notebook upon creation

    - name (str) – The name to identify the algorithm, only uppercase letters, numbers and underscore allowed

    - createdAt (str) – When the python function was created

    - functionVariableMappings (dict) –

    - functionName (str) – The name of the python function to be used

    - codeSource (CodeSource) –

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict